@@ -7,7 +7,7 @@ from oyeahz_base.logger.xlogger import logger
 
 # 获取redis实例
 def get_redis(host: str, port: int) -> Redis:
-    redis.StrictRedis(host=host, port=port, db=0)
+    return redis.StrictRedis(host=host, port=port, db=0)
 
 
 # 通过本地配置获取Redis实例
